def bold(str_body: str) -> str:
    return f'\033[01m{str_body}\033[0m'


def disabled(str_body: str) -> str:
    return f'\033[02m{str_body}\033[0m'


def italic(str_body: str) -> str:
    return f'\033[03m{str_body}\033[0m'


def underline(str_body: str) -> str:
    return f'\033[04m{str_body}\033[0m'


def sharp(str_body: str) -> str:
    return f'\033[07m{str_body}\033[0m'


def invisible(str_body: str) -> str:
    return f'\033[08m{str_body}\033[0m'


def strike_through(str_body: str) -> str:
    return f'\033[09m{str_body}\033[0m'


def double_underline(str_body: str) -> str:
    return f'\033[21m{str_body}\033[0m'


def black(str_body: str) -> str:
    return f'\033[30m{str_body}\033[0m'


def red(str_body: str) -> str:
    return f'\033[31m{str_body}\033[0m'


def green(str_body: str) -> str:
    return f'\033[32m{str_body}\033[0m'


def orange(str_body: str) -> str:
    return f'\033[33m{str_body}\033[0m'


def blue(str_body: str) -> str:
    return f'\033[34m{str_body}\033[0m'


def purple(str_body: str) -> str:
    return f'\033[35m{str_body}\033[0m'


def cyan(str_body: str) -> str:
    return f'\033[36m{str_body}\033[0m'


def light_grey(str_body: str) -> str:
    return f'\033[37m{str_body}\033[0m'


def red_background(str_body: str) -> str:
    return f'\033[41m{str_body}\033[0m'


def green_background(str_body: str) -> str:
    return f'\033[42m{str_body}\033[0m'


def yellow_background(str_body: str) -> str:
    return f'\033[43m{str_body}\033[0m'


def blue_background(str_body: str) -> str:
    return f'\033[44m{str_body}\033[0m'


def purple_background(str_body: str) -> str:
    return f'\033[45m{str_body}\033[0m'


def cyan_background(str_body: str) -> str:
    return f'\033[46m{str_body}\033[0m'


def light_grey_background(str_body: str) -> str:
    return f'\033[47m{str_body}\033[0m'


def dark_grey(str_body: str) -> str:
    return f'\033[90m{str_body}\033[0m'


def light_red(str_body: str) -> str:
    return f'\033[91m{str_body}\033[0m'


def yellow(str_body: str) -> str:
    return f'\033[93m{str_body}\033[0m'


def light_blue(str_body: str) -> str:
    return f'\033[94m{str_body}\033[0m'


def pink(str_body: str) -> str:
    return f'\033[95m{str_body}\033[0m'


def light_cyan(str_body: str) -> str:
    return f'\033[96m{str_body}\033[0m'



from sys import argv, exit
from strstyle import black, blue, blue_background, bold, cyan, \
    cyan_background, dark_grey, disabled, double_underline, green, \
    green_background, invisible, italic, light_blue, light_cyan, light_grey, \
    light_grey_background, light_red, orange, pink, purple, \
    purple_background, red, red_background, sharp, strike_through, underline, \
    yellow, yellow_background


COMMAND_TO_FUNCTION_MAP = {
    "bold": bold,
    "disabled": disabled,
    "italic": italic,
    "underline": underline,
    "sharp": sharp,
    "invisible": invisible,
    "strike-through": strike_through,
    "double-underline": double_underline,
    "black": black,
    "red": red,
    "green": green,
    "orange": orange,
    "blue": blue,
    "purple": purple,
    "cyan": cyan,
    "light-grey": light_grey,
    "red-background": red_background,
    "green-background": green_background,
    "yellow-background": yellow_background,
    "blue-background": blue_background,
    "purple-background": purple_background,
    "cyan-background": cyan_background,
    "light-grey-background": light_grey_background,
    "dark-grey": dark_grey,
    "light-red": light_red,
    "yellow": yellow,
    "light-blue": light_blue,
    "pink": pink,
    "light-cyan": light_cyan,
}


def main():
    if len(argv) < 3:
        print("your command should look like 'str-style [styles] <string>'")
        exit(1)
    try:
        s = argv[-1]
        for style in argv[1:-1]:
            s = COMMAND_TO_FUNCTION_MAP[style](s)
        print(s)

    except KeyError:
        print("\n".join([
            f"style: {style} does not exist available options are:",
            *list(map(lambda x: f"- {x}",
                      COMMAND_TO_FUNCTION_MAP.keys())),
        ]))
        exit(1)


if __name__ == "__main__":  # pragma: no cover
    main()
